@@ -914,6 +914,26 @@ void avx2_f32_seq(F32PTR p,F32 x0,F32 dX,int N) {
     }     
     _mm256_zeroupper();    
 }
+void avx2_i32_seq(I32PTR p,I32 x0,I32 dX,int N) {
+    __m256i X;
+    {
+        __m128i tmp=_mm_cvtsi64_si128(0x0706050403020100);
+        __m256i v1to7=_mm256_cvtepu8_epi32(tmp);
+        __m256i  DX=_mm256_mullo_epi32(v1to7,set1_i32(dX)); 
+        X=addi32(set1_i32(x0),DX);
+    }
+    __m256i DX8=set1_i32(dX * 8);
+    int i=0;
+    for (; i < N - (NF - 1); i+=NF) {
+        storei(p+i,X);
+        X=addi32(X,DX8);
+    }
+    int n=N - i;
+    if (n > 0) {
+        maskstorei(p+i,GetMoveMask(n),X);
+    }
+    _mm256_zeroupper();
+}
 void avx2_f32_to_f64_inplace(F32PTR data32,int N) {
     F64PTR data64=data32;
     int i=N - 8;
@@ -1303,7 +1323,21 @@ static INLINE void fma_f32_axpy_inplace( const F32 a,const F32PTR x,F32PTR y,con
         maskstore(y+i,GetMoveMask(n),_mm256_fmadd_ps(load(x+i),C,load(y+i)) );
     _mm256_zeroupper();
 }
-static INLINE void avx2_f32_axpy_inplace(const F32 a,const F32PTR x,F32PTR y,const int N) {
+static  void avx2_f32_axpy_inplace(const F32 a,const F32PTR x,F32PTR y,const int N) {
+    __m256  C=set1(a);
+    int i=0;
+    for (; i < N - (NF3 - 1); i+=NF3)
+        store(y+i,add(mul(load(x+i),C),load(y+i))),
+        store(y+i+8,add(mul(load(x+i+8),C),load(y+i+8))),
+        store(y+i+16,add(mul(load(x+i+16),C),load(y+i+16)));
+    for (; i < N - (NF - 1); i+=NF)
+        store(y+i,add(mul(load(x+i),C),load(y+i)));
+    int n=N - i;
+    if (n > 0) 
+        maskstore(y+i,GetMoveMask(n),add(mul(load(x+i),C),load(y+i)));
+    _mm256_zeroupper();
+}
+static INLINE void __avx2_f32_axpy_inplace(const F32 a,const F32PTR x,F32PTR y,const int N) {
     __m256  C=set1(a);
     int i=0;
     for (; i < N - (NF3 - 1); i+=NF3)
@@ -1317,7 +1351,7 @@ static INLINE void avx2_f32_axpy_inplace(const F32 a,const F32PTR x,F32PTR y,con
         maskstore(y+i,GetMoveMask(n),add(mul(load(x+i),C),load(y+i))  );
     _mm256_zeroupper();
 }
-static INLINE void avx2_f32_ax1ax2py_inplace(const F32PTR a,const F32PTR x1,const F32PTR x2,F32PTR y,const int N) {
+static INLINE void __avx2_f32_ax1ax2py_inplace(const F32PTR a,const F32PTR x1,const F32PTR x2,F32PTR y,const int N) {
     __m256  C1=set1(a[0]);
     __m256  C2=set1(a[1]);
     int i=0;
@@ -1344,19 +1378,19 @@ void avx2_f32_gemv_Xb(int N,int K,F32PTR X,int lda,F32PTR b,F32PTR C)
     for (; row < N - (256 * 2 -1); row+=256*2) {
         int col=0;
         for (; col < K-1; col+=2) {
-            avx2_f32_ax1ax2py_inplace(b+col,X+col * lda+row,X+(col+1) * lda+row,C+row,256 * 2);
+            __avx2_f32_ax1ax2py_inplace(b+col,X+col * lda+row,X+(col+1) * lda+row,C+row,256 * 2);
         }
         if(col<K)
-            avx2_f32_axpy_inplace(b[col],X+col * lda+row,C+row,256 * 2);
+            __avx2_f32_axpy_inplace(b[col],X+col * lda+row,C+row,256 * 2);
     }
     int n=N - row;
     if (n > 0) {
         int col=0;
         for (; col < K-1; col+=2) {
-            avx2_f32_ax1ax2py_inplace(b+col,X+col * lda+row,X+(col+1) * lda+row,C+row,n);
+            __avx2_f32_ax1ax2py_inplace(b+col,X+col * lda+row,X+(col+1) * lda+row,C+row,n);
         }
         if(col<K)
-            avx2_f32_axpy_inplace(b[col],X+col * lda+row,C+row,n);
+            __avx2_f32_axpy_inplace(b[col],X+col * lda+row,C+row,n);
     }
 }
 static INLINE I32 _avx2_f32_findindex_LT(F32PTR  x,I32PTR indices,F32 value,int N) {
@@ -1719,47 +1753,47 @@ void avx2_f32_hinge_neg(const F32PTR X,const F32PTR Y,const F32 knot,const int N
     }
     int n=N - i;
     if (n > 0) {
-        __m256 d1=sub(load(X+i),C);   maskstore(Y+i,GetMoveMask(n),_mm256_blendv_ps(O,d1,_mm256_cmp_ps(d1,O,_CMP_GE_OQ))); 
+        __m256 d1=sub(C,load(X+i));   maskstore(Y+i,GetMoveMask(n),_mm256_blendv_ps(O,d1,_mm256_cmp_ps(d1,O,_CMP_GE_OQ))); 
     }
     _mm256_zeroupper();    
 }
-void avx2_f32_step_pos(const F32PTR X,const F32PTR Y,const F32 knot,const int N){    
+void avx2_f32_step_pos(const F32PTR X,const F32PTR Y,const F32PTR Z,const F32 knot,const int N){
     __m256  O=set0();
     __m256  I=set1(1.0);
     __m256  C=set1(knot);
     int i=0;
     for (; i < N - (NF4 - 1); i+=NF4) {
-        __m256 d1=sub(load(X+i),C);   store(Y+i,_mm256_blendv_ps(O,I,_mm256_cmp_ps(d1,O,_CMP_GE_OQ))); 
-        __m256 d2=sub(load(X+i+NF),C);   store(Y+i+NF,_mm256_blendv_ps(O,I,_mm256_cmp_ps(d2,O,_CMP_GE_OQ))); 
-        __m256 d3=sub(load(X+i+NF2),C);  store(Y+i+NF2,_mm256_blendv_ps(O,I,_mm256_cmp_ps(d3,O,_CMP_GE_OQ))); 
-        __m256 d4=sub(load(X+i+NF3),C);  store(Y+i+NF3,_mm256_blendv_ps(O,I,_mm256_cmp_ps(d4,O,_CMP_GE_OQ))); 
+        __m256 d1=sub(load(X+i),C);   store(Z+i,_mm256_blendv_ps(O,load(Y+i),_mm256_cmp_ps(d1,O,_CMP_GE_OQ))); 
+        __m256 d2=sub(load(X+i+NF),C);   store(Z+i+NF,_mm256_blendv_ps(O,load(Y+i+NF),_mm256_cmp_ps(d2,O,_CMP_GE_OQ))); 
+        __m256 d3=sub(load(X+i+NF2),C);  store(Z+i+NF2,_mm256_blendv_ps(O,load(Y+i+NF2),_mm256_cmp_ps(d3,O,_CMP_GE_OQ))); 
+        __m256 d4=sub(load(X+i+NF3),C);  store(Z+i+NF3,_mm256_blendv_ps(O,load(Y+i+NF3),_mm256_cmp_ps(d4,O,_CMP_GE_OQ))); 
     }
     for (; i < N - (NF - 1); i+=NF) {
-        __m256 d1=sub(load(X+i),C);   store(Y+i,_mm256_blendv_ps(O,I,_mm256_cmp_ps(d1,O,_CMP_GE_OQ))); 
+        __m256 d1=sub(load(X+i),C);     store(Z+i,_mm256_blendv_ps(O,load(Y+i),_mm256_cmp_ps(d1,O,_CMP_GE_OQ))); 
     }
     int n=N - i;
     if (n > 0) {
-        __m256 d1=sub(load(X+i),C);   maskstore(Y+i,GetMoveMask(n),_mm256_blendv_ps(O,I,_mm256_cmp_ps(d1,O,_CMP_GE_OQ))); 
+        __m256 d1=sub(load(X+i),C);   maskstore(Z+i,GetMoveMask(n),_mm256_blendv_ps(O,load(Y+i),_mm256_cmp_ps(d1,O,_CMP_GE_OQ))); 
     }
     _mm256_zeroupper();    
 }
-void avx2_f32_step_neg(const F32PTR X,const F32PTR Y,const F32 knot,const int N){
+void avx2_f32_step_neg(const F32PTR X,const F32PTR Y,const F32PTR Z,const F32 knot,const int N){
     __m256  O=set0();
     __m256  I=set1(1.0);
     __m256  C=set1(knot);
     int i=0;
     for (; i < N - (NF4 - 1); i+=NF4) {
-        __m256 d1=sub(load(X+i),C);   store(Y+i,_mm256_blendv_ps(I,O,_mm256_cmp_ps(d1,O,_CMP_GE_OQ))); 
-        __m256 d2=sub(load(X+i+NF),C);   store(Y+i+NF,_mm256_blendv_ps(I,O,_mm256_cmp_ps(d2,O,_CMP_GE_OQ))); 
-        __m256 d3=sub(load(X+i+NF2),C);  store(Y+i+NF2,_mm256_blendv_ps(I,O,_mm256_cmp_ps(d3,O,_CMP_GE_OQ))); 
-        __m256 d4=sub(load(X+i+NF3),C);  store(Y+i+NF3,_mm256_blendv_ps(I,O,_mm256_cmp_ps(d4,O,_CMP_GE_OQ))); 
+        __m256 d1=sub(load(X+i),C);   store(Z+i,_mm256_blendv_ps(load(Y+i ),O,_mm256_cmp_ps(d1,O,_CMP_GE_OQ))); 
+        __m256 d2=sub(load(X+i+NF),C);   store(Z+i+NF,_mm256_blendv_ps(load(Y+i+NF),O,_mm256_cmp_ps(d2,O,_CMP_GE_OQ))); 
+        __m256 d3=sub(load(X+i+NF2),C);  store(Z+i+NF2,_mm256_blendv_ps(load(Y+i+NF2),O,_mm256_cmp_ps(d3,O,_CMP_GE_OQ))); 
+        __m256 d4=sub(load(X+i+NF3),C);  store(Z+i+NF3,_mm256_blendv_ps(load(Y+i+NF3),O,_mm256_cmp_ps(d4,O,_CMP_GE_OQ))); 
     }
     for (; i < N - (NF - 1); i+=NF) {
-        __m256 d1=sub(load(X+i),C);   store(Y+i,_mm256_blendv_ps(I,O,_mm256_cmp_ps(d1,O,_CMP_GE_OQ))); 
+        __m256 d1=sub(load(X+i),C);     store(Z+i,_mm256_blendv_ps(load(Y+i),O,_mm256_cmp_ps(d1,O,_CMP_GE_OQ))); 
     }
     int n=N - i;
     if (n > 0) {
-        __m256 d1=sub(load(X+i),C);   maskstore(Y+i,GetMoveMask(n),_mm256_blendv_ps(I,O,_mm256_cmp_ps(d1,O,_CMP_GE_OQ))); 
+        __m256 d1=sub(load(X+i),C);   maskstore(Z+i,GetMoveMask(n),_mm256_blendv_ps(load(Y+i),O,_mm256_cmp_ps(d1,O,_CMP_GE_OQ))); 
     }
     _mm256_zeroupper();     
 }
@@ -1796,6 +1830,7 @@ void SetupVectorFunction_AVX2() {
     f32_minidx=&avx2_f32_minidx;
     f32_diff_back=& avx2_f32_diff_back;
     f32_seq=& avx2_f32_seq;
+    i32_seq=&avx2_i32_seq;
     f32_to_f64_inplace=&avx2_f32_to_f64_inplace;
     f64_to_f32_inplace=&avx2_f64_to_f32_inplace;
     i32_to_f32_scaleby_inplace=&avx2_i32_to_f32_scaleby_inplace;
@@ -1816,8 +1851,9 @@ void SetupVectorFunction_AVX2() {
     f32_scale_inplace=avx2_f32_scale_inplace;
     f32_hinge_pos=avx2_f32_hinge_pos;
     f32_hinge_neg=avx2_f32_hinge_neg;
-     f32_step_pos=avx2_f32_step_pos;
+    f32_step_pos=avx2_f32_step_pos;
 	f32_step_neg=avx2_f32_step_neg;
+    f32_axpy_inplace=avx2_f32_axpy_inplace;
 }
 #else
 static char a='a';
